@@ -1,8 +1,10 @@
+from __future__ import absolute_import
+from builtins import object
 import os
-from error import FileNotFoundError, CreateFolderError, FileNotWritableError, FileNotReadableError, RemoveFolderError, RemoveFileError, ScssError, ParseError
+from .error import FileNotFoundError, CreateFolderError, FileNotWritableError, FileNotReadableError, RemoveFolderError, RemoveFileError, ScssError, ParseError, TranscryptError
 from shutil import copy2, copytree, rmtree
-from slimit import minify
-from cssmin import cssmin
+from grace.py27.slimit import minify
+from grace.py27.cssmin import cssmin
 from execjs import ProgramError
 import re
 import scss
@@ -10,6 +12,8 @@ import sys
 import tempfile
 import coffeescript
 import traceback
+import subprocess
+import shlex
 
 
 class Build(object):
@@ -30,7 +34,10 @@ class Build(object):
             raise CreateFolderError('Could not create the project folder.')
 
         try:
-            self._build_javascript()
+            if self._config['using_transcrypt']:
+                self._build_transcrypt()
+            else:
+                self._build_javascript()
             self._build_style()
             self._build_html()
             self._build_libraries()
@@ -38,6 +45,53 @@ class Build(object):
         except:
             raise
 
+    def _build_transcrypt(self):
+        os.chdir('src')
+
+        js_name = self._config['js_name'] + '.py'
+        source = os.path.join(self._cwd, 'src', js_name)
+        dest = os.path.join(self._config['build_path'], self._config['js_name'] + '.js')
+
+        if not os.path.exists(source):
+            raise FileNotFoundError('Could not find the main script ("' + source + '") for transcrypt.')
+
+        args = 'transcrypt -b '
+        if not self._config['minify_js']:
+            args += '-n '
+        args += source
+
+        try:
+            popen = subprocess.Popen(shlex.split(args), stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            output, error = popen.communicate()
+
+            if error != b'':
+                raise TranscryptError('Could not transpile the file at ' + source)
+        except Exception as e:
+            raise e
+
+        if os.path.exists(dest):
+            os.remove(dest)
+
+        try:
+            if self._config['minify_js']:
+                built_js_name = self._config['js_name'] + '.min.js'
+            else:
+                built_js_name = self._config['js_name'] + '.js'
+
+            copy2(os.path.join(self._cwd, 'src', '__javascript__', built_js_name), dest)
+        except Exception as e:
+            raise FileNotFoundError('Could not find the transpiled javascript file.')
+
+        for root, dirs, files in os.walk(os.path.join(self._cwd, 'src')):
+            for d in dirs:
+                if d == '__javascript__':
+                    try:
+                        rmtree(os.path.join(root, d))
+                    except Exception as e:
+                        raise FolderNotFoundError('Could not delete a transcrypt generated folder: "' + os.path.join(root, d) + '"')
+
+        os.chdir(self._cwd)
+
     def _build_javascript(self):
         js_name = self._config['js_name'] + '.js'
         source = os.path.join(self._cwd, 'src', js_name)
@@ -78,7 +132,7 @@ class Build(object):
         if self._config['minify_js']:
             js_string = minify(js_string, mangle=True, mangle_toplevel=False)
 
-        f.write(js_string.encode('utf-8'))
+        f.write(js_string)
         f.close()
 
     def _concat_javascript(self, source, as_coffee=False):
@@ -107,7 +161,6 @@ class Build(object):
         js_string = ''
 
         for line in f:
-            line = line.decode('utf-8')
             line = line.replace('##BUILDVERSION##', self._config['version'])
 
             if as_coffee:
@@ -118,9 +171,15 @@ class Build(object):
             if match:
                 include_f = None
                 include_path = match.group(1)
+                files_dir = os.path.join(self._cwd, 'src', 'javascript')
+                if not os.path.exists(files_dir):
+                    files_dir = os.path.join(self._cwd, 'src', 'coffeescript')
+                    if not os.path.exists(files_dir):
+                        raise FileNotFoundError('There is not javascript or coffeescript folder present in the src director.')
+
                 if sys.platform.startswith('win32'):
                     include_path = include_path.replace('/', '\\')
-                include_path = os.path.join(self._cwd, 'src', 'javascript', include_path)
+                include_path = os.path.join(files_dir, include_path)
 
                 if os.path.exists(include_path + '.js'):
                     include_path = include_path + '.js'
@@ -152,7 +211,7 @@ class Build(object):
                 js_string = coffeescript.compile(js_string)
             except ProgramError as e:
                 filename = f.name.replace(self._cwd, '')[1:]
-                msg = e.message.replace('stdin', filename)
+                msg = ''.join(map(str, e.args)).replace('stdin', filename)
 
                 raise ParseError('Error while parsing CoffeeScript\n' + msg)
 
@@ -220,8 +279,11 @@ class Build(object):
                         css_string = compiler.compile(scss_filename)
                     except (scss.errors.SassEvaluationError, scss.errors.SassSyntaxError, scss.errors.SassParseError) as e:
                         raise ScssError(traceback.format_exc(0))
+                    except scss.errors.SassError as e:
+                        elist = traceback.format_exception_only(type(e), e)
+                        raise ScssError(''.join(elist))
                     except:
-                        raise FileNotFoundError('Could not find your scss style file.')
+                        raise FileNotFoundError('Could not compile your scss style file.')
 
                     try:
                         css_file = open(css_filename, 'w+')
