@@ -1,4 +1,7 @@
-from error import FileNotWritableError, RemoveFileError, MissingKeyError
+from __future__ import print_function
+from __future__ import absolute_import
+from builtins import object
+from .error import FileNotWritableError, RemoveFileError, MissingKeyError
 import os
 import zipfile
 
@@ -14,14 +17,14 @@ class Zip(object):
             self._zip_path = os.path.join(self._config['zip_path'])
 
         if 'zip_name' not in self._config:
-            self._zip_name = self._config['name'] + '_' + self._config['version'] + '.zip'
+            self._zip_name = self._config['name'] + '-' + self._config['version'] + '.zip'
         else:
             self._zip_name = self._config['zip_name']
 
     def run(self, testname):
         if self._config['test']:
             if testname is None:
-                print 'No tests to build.'
+                print('No tests to build.')
                 return
 
             name = self._config['name'] + '_' + testname
